from __future__ import annotations

import mknodes as mk


def test_modulepage():
    mk.MkModulePage(mk)
